@@ -462,10 +462,14 @@ def _defaultVars(_userDict, _inputDict, _GlobLoc, **varDict):
 
     if len(set(_userDict.keys()).difference(set(varDict.keys()))):
         var = set(_userDict.keys()).difference(set(varDict.keys()))
+        txt = 'Unexpected argument `%s` passed to OMFIT script.\nSupported defaultVars are `%s`.' % (
+            ', '.join(var),
+            ', '.join(varDict.keys()),
+        )
         if strict_defaultVars:
-            raise ValueError('Unexpected argument passed to OMFIT script: ' + ','.join(var))
+            raise ValueError(txt)
         else:
-            printw('Unexpected argument passed to OMFIT script: ' + ','.join(var))
+            printw(txt)
     if len(set(_userDict.keys()).intersection(set(_inputDict.keys()))):
         var = set(_userDict.keys()).intersection(set(_inputDict.keys()))
         printw('Reserved argument passed to OMFIT script: ' + ','.join(var))
@@ -864,7 +868,7 @@ print(kw1)
 
         # cleanup: keep only the most recent n backedup files
         n = 1000
-        files = glob.glob(OMFITscriptsBackupDir + "/*")
+        files = [f for f in glob.glob(OMFITscriptsBackupDir + "/*") if os.path.exists(f)]
         files.sort(key=lambda x: os.path.getmtime(x))
         files = list(reversed(files))
         for k in reversed(list(range(n, len(files)))):
@@ -1624,7 +1628,7 @@ class OMFITpythonGUI(_OMFITpython):
         # allow only one GUI instance from this OMFITpythonGUI object
         if kw.pop('singleGUIinstance', True):
             for item in list(OMFITx._GUIs.keys()):
-                if self.filename == OMFITx._GUIs[item].pythonFile.filename:
+                if id(self) == id(OMFITx._GUIs[item].pythonFile):
                     OMFITx._clearClosedGUI(OMFITx._GUIs[item].top)
 
         if _relLoc is None:
